@@ -6,8 +6,8 @@ from apicase.schema import BaseModel
 from apicase.client.router import APIRouter
 from apicase.client.reuquest import APIRequest, HttpSession
 from apicase.client.reuquest import session
-from apicase.assertion.comparators import assertJSON
-from apicase.assertion.diff import DiffJSON
+from apicase.assertion.comparators import assertJSON, AssertJson
+from apicase.assertion.diff import DiffJson
 from apicase.common.enumeration import (
     BodyTypeEnum,
 )
